@@ -1,35 +1,25 @@
 #!/usr/bin/python
-# $Id: wlink.py 1003 2014-08-16 16:21:18Z mwall $
+# $Id: wlink.py 1113 2014-11-14 05:04:51Z mwall $
 # Copyright 2014 Matthew Wall
-#
-# weewx driver for WeatherLink web sites
-# download data from a weatherlink site for use in weewx
-#
-# This program is free software: you can redistribute it and/or modify it under
-# the terms of the GNU General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or any later version.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE.
-#
-# See http://www.gnu.org/licenses/
+"""weewx driver for WeatherLink web sites
+   download data from a weatherlink site for use in weewx
 
-# To use this driver:
-#
-# 1) copy this file to the weewx user directory
-#
-#    cp wlink.py /home/weewx/bin/user
-#
-# 2) configure weewx.conf
-#
-# [Station]
-#     ...
-#     station_type = WeatherLink
-# [WeatherLink]
-#     username = USERNAME
-#     password = PASSWORD
-#     driver = user.wlink
+To use this driver:
+
+1) copy this file to the weewx user directory
+
+   cp wlink.py /home/weewx/bin/user
+
+2) configure weewx.conf
+
+[Station]
+    ...
+    station_type = WeatherLink
+[WeatherLink]
+    username = USERNAME
+    password = PASSWORD
+    driver = user.wlink
+"""
 
 # FIXME: there are unresolved timezone issues in this code.  if you grab data
 # from a weatherlink site that is in a time zone other than the one in which
@@ -56,10 +46,9 @@ import time
 import urllib2
 from HTMLParser import HTMLParser
 
-import weewx.abstractstation
-import weewx.wxformulas
+import weewx.drivers
 
-DRIVER_VERSION = '0.2'
+DRIVER_VERSION = "0.3"
 
 def logmsg(dst, msg):
     syslog.syslog(dst, 'wlink: %s' % msg)
@@ -77,10 +66,9 @@ def logerr(msg):
     logmsg(syslog.LOG_ERR, msg)
 
 def loader(config_dict, engine):
-    station = WeatherLink(**config_dict['WeatherLink'])
-    return station
+    return WeatherLink(**config_dict['WeatherLink'])
 
-class WeatherLink(weewx.abstractstation.AbstractStation):
+class WeatherLink(weewx.drivers.AbstractDevice):
     """weewx driver to download data from WeatherLink web sites
     
     Parse the web page for 'loop' data.  This happens every 60 seconds.
@@ -112,7 +100,7 @@ class WeatherLink(weewx.abstractstation.AbstractStation):
             data = self.get_data("http://www.weatherlink.com/user/%s/index.php"
                                  "?view=main&headers=0&type=2" % self.username)
             packet = {
-                'dateTime': int(time.time()+0.5),
+                'dateTime': int(time.time() + 0.5),
                 'usUnits': weewx.US, # type 2 is US imperial
                 }
             packet.update(self.parse_page(data))
@@ -199,12 +187,6 @@ class WeatherLink(weewx.abstractstation.AbstractStation):
 
         if packet['windSpeed'] is None or packet['windSpeed'] == 0:
             packet['windDir'] = None
-        T = packet['outTemp']
-        R = packet['outHumidity']
-        W = packet['windSpeed']
-        packet['dewpoint'] = weewx.wxformulas.dewpointF(T, R)
-        packet['heatindex'] = weewx.wxformulas.heatindexF(T, R)
-        packet['windchill'] = weewx.wxformulas.windchillF(T, W)
         packet['interval'] = self.archive_interval / 60
         return packet
 
